.. SPDX-FileCopyrightText: 2020-2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.metadata package
=========================

Modules
-------
.. toctree::
   :maxdepth: 1

   metadata/oc_ocdm.metadata.metadata_entity
   metadata/oc_ocdm.metadata.metadata_set

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   metadata/oc_ocdm.metadata.entities
